@@ -56,10 +56,10 @@ bool compareX(std::vector<someType> a, std::vector<someType> b) {
         if ((*ita)>(*itb)) {
             return(false);
         } else {
-#ifndef NO_R_CONSOLE // NOT NO_R = if DLL
+#ifndef NO_R_CONSOLE // ifNdef = NOT NO_R = if DLL
 // called from R code: the arrya should already be sorted so that the order of
 // krig coefficients is the same in C and R code
-            if ((*ita)!=(*itb)) Rf_error("(!) From compareX() in DLL : parameter points provided by R call not sorted. \n");
+            if ((*ita)!=(*itb)) Rcpp::stop("(!) From compareX() in DLL : parameter points provided by R call not sorted. \n");
 #endif
             ita++;itb++;
         }
@@ -155,7 +155,7 @@ const TypeforBrent ZEPS=(100.*EPSILON);
     exit(-1);
 #else
      REprintf("%d iterations.",ITMAX); // typically goes to
-     Rf_error("(!) From CSmooth::brent(): Too many iterations.\n");
+     Rcpp::stop("(!) From CSmooth::brent(): Too many iterations.\n");
 #endif
 return fx;
 }
